@@ -14,7 +14,7 @@ sub new_sock {
         Proto     => 'tcp',
         Listen    => 5,
         Type      => SOCK_STREAM,
-        ReuseAddr => 1,
+        (($^O eq 'MSWin32') ? () : (ReuseAddr => 1)),
     ) or die "Cannot open server socket: $!";
     return $sock;
 }
